"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const prettier_1 = require("prettier");
const convertScopedCssForEmotion_1 = require("./convertScopedCssForEmotion");
const convertScopeToModuleName_1 = require("./convertScopeToModuleName");
const getCssIndexedByScope_1 = require("./getCssIndexedByScope");
const getRequiredScopes_1 = require("./getRequiredScopes");
const getScopePath_1 = require("./getScopePath");
const getScopeRelativePath_1 = require("./getScopeRelativePath");
function convertCssForEmotion(css) {
    const cssForEmotion = new Map();
    const scopesByDirname = new Map();
    const cssIndexedByScope = getCssIndexedByScope_1.getCssIndexedByScope(css);
    const knownScopes = new Set([...cssIndexedByScope.keys()]);
    cssIndexedByScope.forEach((currentCss, currentScope) => {
        let source = "";
        if (currentScope === "root") {
            source += 'import { injectGlobal } from "emotion";\n';
        }
        else {
            source += 'import { css } from "emotion";\n';
        }
        source += "\n";
        const requiredScopes = getRequiredScopes_1.getRequiredScopes(currentCss, currentScope, knownScopes);
        source += [...requiredScopes]
            .sort()
            .map((requiredScope) => {
            const mName = convertScopeToModuleName_1.convertScopeToModuleName(requiredScope);
            const mFilename = getScopeRelativePath_1.getScopeRelativePath(currentScope, requiredScope, knownScopes);
            return `import { ${mName} } from "./${mFilename}";`
                .replace("./../", "../")
                .replace('.js"', '"');
        })
            .join("\n");
        source += "\n\n";
        const convertedScopedCssForEmotion = convertScopedCssForEmotion_1.convertScopedCssForEmotion(currentCss, currentScope, knownScopes);
        if (currentScope === "root") {
            source += `export default () => css\`${convertedScopedCssForEmotion}\`;\n`;
        }
        else {
            source += `export const ${convertScopeToModuleName_1.convertScopeToModuleName(currentScope)} = css\`${convertedScopedCssForEmotion}\`;\n`;
        }
        source = prettier_1.format(source, {
            parser: "typescript",
            tabWidth: 4,
        });
        if (currentScope === "root") {
            source = source.replace(/ css\`/m, " injectGlobal`");
        }
        const scopePath = getScopePath_1.getScopePath(currentScope, knownScopes);
        const dirname = path.dirname(scopePath);
        if (scopesByDirname.has(dirname) === false) {
            scopesByDirname.set(dirname, new Set());
        }
        scopesByDirname.get(dirname).add(currentScope);
        cssForEmotion.set(scopePath, source);
    });
    return cssForEmotion;
}
exports.convertCssForEmotion = convertCssForEmotion;
